# LatestOS

Latest OS version checker for Linux Distros using the Arizona Mirror

It currently checks the following distros:
- arch
- ubuntu
- fedora
- centos

## Installation
LatestOS requires [Python 3](https://www.python.org/downloads/) to run.

Install with pip:

```sh
pip install latestos
```

For UNIX-based systems with both Python 2 and Python 3 installed:

```sh
pip3 install latestos
```

## How to run?

To be added
